tornado-rest-client: Tornado API Client Framework
=================================================

|build_status|_ |doc_status|_ |pypi_ver|_ |pypi_download|_

The ``tornado_rest_client`` framework provides a quick and easy way to build
generic API clients for JSON REST-based APIs. The framework provides robust and
reliable retry mechanisms, error handling and exception raising all within a
simple to use class structure.

Documentation
-------------

Documentation is hosted at `https://tornado-rest-client.readthedocs.org <https://tornado-rest-client.readthedocs.org>`_

.. |build_status| image:: https://travis-ci.org/Nextdoor/tornado_rest_client.svg?branch=master
.. _build_status: https://travis-ci.org/Nextdoor/tornado_rest_client
.. |doc_status| image:: https://readthedocs.org/projects/tornado-rest-client/badge/?version=latest
.. _doc_status: https://tornado_rest_client.readthedocs.org
.. |pypi_ver| image:: https://pypip.in/d/tornado_rest_client/badge.png
.. _pypi_ver: https://pypi.python.org/pypi/tornado_rest_client
.. |pypi_download| image:: https://badge.fury.io/py/tornado_rest_client.png
.. _pypi_download: https://pypi.python.org/pypi/tornado_rest_client
